\name{fit.li.wong}
\alias{fit.li.wong}
\title{Fit Li and Wong model to probe set}
\description{Fits the model described in Li and Wong (2001) to a probe
  set with I chips and J probes.}
}
\usage{
fit.li.wong(data.matrix, remove.outliers=T, normal.array.quantile=0.5,
 normal.resid.quantile=0.9, large.threshold=3, large.variation=0.8,
outlier.fraction=0.14, delta=1e-06, maxit=50, outer.maxit=50, verbose=F)
}
\arguments{
  \item{data.matrix}{a I x J matrix containg the probe set
    data. Typically the i,j entry will contain the pm-mm value foe probe
    pair j in chip i. Another typical use, is to use pm instead of mm.}
  \item{remove.outliers}{logical value indicating if the algorithm
    will remove outliers according to the procedure described in Li and
    Wong (2001).}
  \item{large.threshold}{used to define outliers.}
  \item{normal.array.quantile}{quantile to be used when determining what
    a normal SD is. probes or chips having estimates with SDs bigger
    than the quantile \code{normal.array.quantile} of all SDs x
    \code{large.threshold} }
  \item{normal.resid.quantile}{any residual  bigger than the
    \code{normal.resid.quantile} quantile of all residuals x
    \code{large.threshold} is considered an outlier}
  \item{large.variation}{any probe or chip describing more than this
    much total variation is considered an outlier}
  \item{outlier.fraction}{this is the maximum fraction of single
    outliers that can be in the same probe or chip.}
  \item{delta}{ numerical value used to define the stopping
    criterion. }
  \item{maxit}{ maximum number of iterations when fitting the model.}
  \item{outer.maxit}{ maxumum number of iterations of defined outliers.}
  \item{verbose}{logical value. If \code{TRUE} information is given of
    the status of the algorithm.}
}
\details{Please refer to references.}
\value{A list containing the fitted parameters and relevant information.
  \item{theta}{fitted thetas.}
  \item{phi}{fitted phis.}
  \item{sigma.eps}{estimated standard deviation of the error term.}
  \item{sigma.theta}{estimated standard error of theta.}
  \item{sigma.phi}{estimated standard error of phis.}
  \item{theta.outliers}{logical vector describing which chips (thetas) are considered
    outliers (\code{TRUE}).}
  \item{phi.outliers}{logical vector describing which probe sets (phis) are
    considered outliers (\code{TRUE})}
  \item{convergence1}{logical value. If \code{FALSE} the algorithm did
    not converge when fitting the phis and thetas.}
  \item{convergence2}{logical value. If \code{FALSE} the algorithm did
    not converge in deciding what are outliers.}
  \item{iter}{number of iterations needed to achieve convergence.}
  \item{delta}{difference between thetas when iteration stopped.}
}
\references{Li, C. and Wong, W.H. (2001) Genome Biology 2, 1-11,
  Li, C. and Wong, W.H. (2001) Proc. Natl. Acad. Sci USA 98, 31-6}
\author{Rafael A. Irizarry, Cheng Li, Fred A. Wright, Ben Bolstad}
\seealso{ \code{\link{li.wong}}}




