\name{read.affy}
\alias{read.affy}

\title{Affymetrix Data Input }
\description{Reads a file containing probe pair information in table format
  and creates an Affymetrix information object (\code{\link{affy.object}}).
}
\usage{
read.affy(file, chip.names=NULL, keep.controls=F)
}
\arguments{
  \item{file}{the name of the file which the data are to be read
    from. This file must be in the format produced by the function
    \code{\link{convert.affy}} or the 
    \code{\link{cel2tab.pl}} perl script provided with this package.}
  \item{chip.names}{character vector containing the names to be used
    for the different chips.}
  \item{keep.controls}{ a logical value indicating if the information
    from the control probes should be retured.}
}
\details{
  The file to be read must have a specific format. If the  the function
  \code{convert.affy} or 
  \code{cel2tab.pl} are used one does not need to worry about this.
  The first row of the file must contain the column names. These should
  be \code{probe.name}, \code{number},  \code{pm.or.mm},  \code{x},
  \code{y}, and the names of the chips.
  The first five should be a 
  column  contain the probe name (usually gene accession numbers), a
  column contains the probe number, a column containing a 1,0, -1 if the row corresponds to a pm,
  mm, or control respectively, a column with the probe row on the chip,
  and a column with the probe colimn on the chip. The rest of the
  columns should correspond to the intensities read for the
  different chips.

  If the chip.names are \code{NULL} the names of the CEL files will be
  used as chip.names.

  If keep.control=T, \code{read.affy} returns an "extended"
  \code{affy.object}. Basically, the same information given for the
  probe pairs is given for the controls. The component names start with
  \code{control}.

  Some of the probes on the chips don't have an entry in the CDF
  file. These are given the name \code{no_name} and are considered controls.
}
\value{
  an \code{\link{affy.object}} which has the following components
  (components starting with \code{control} are only returned if \code{keep.control=T}): 
   \item{nchips}{number of chips.}
  \item{nprob}{number of probe pairs.}
  \item{probe.names}{a characater vector of length \code{nprob} with the
    probe names for each probe pair.}
  \item{pm}{a \code{nprob} by \code{nchips} matrix with the pm intensities.}
  \item{mm}{a \code{nprob} by \code{nchips} matrix with the mm intensities.}
  \item{chip.names}{a character vector of length nchips with the names
    of each chip.}
  \item{probe.number}{the probe number for each probe} 
  \item{x}{a vector containing the row number of the pm, for each
    probe pair, on the chips.}
  \item{y}{a vector containing the column number of the pm, for each
    probe pair, on the chips.}
  \item{ncol}{the number of rows on the chips.}
  \item{nrow}{the number of columns on the chips.}
  \item{control.names}{character vector with the names of the control
    probes.}
  \item{control.values}{ a \code{nprob} by \code{nchips} matrix with
    the intensities.}
  \item{control.x}{a vector containing the row number of the controls.}
  \item{control.y}{a vector containing the column number of the controls.}
  \item{control.probe.numbers}{probe numbers for control}
}
\references{ Affymetrix (1999) Gene Chip Analysis Suite User Guide
  (Affymetrix, Santa Clara)}
\author{Rafael A. Irizarry}
\seealso{\code{\link{convert.affy}},\code{\link{cel2tab.pl}}}





